==> haskell-deque-0.4.4.2-107.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.2
visibility:           public
id:                   deque-0.4.4.2-DIYwTC10ib023LsaHVSmhq
key:                  deque-0.4.4.2-DIYwTC10ib023LsaHVSmhq
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  64693dc1ba0d3d5e7275438a14510f09
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.2-DIYwTC10ib023LsaHVSmhq
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z mtl-2.3.1
    strict-list-0.1.7.6-JIfe1DsCbLp7n7ZCmVBiDO

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deque-0.4.4.2-108-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.2
visibility:           public
id:                   deque-0.4.4.2-Kea7RzF2A0mJIBYuENsb0X
key:                  deque-0.4.4.2-Kea7RzF2A0mJIBYuENsb0X
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  f959379f13ac97d5c4f0fff27479094f
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/deque-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.2-Kea7RzF2A0mJIBYuENsb0X
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD mtl-2.3.1
    strict-list-0.1.7.6-33IElGv1emkKg5CjRd99pG

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
